##wtot

-  A terminal word query tool by Baidufanyi API

Install
~~~~~~~

::

   pip install wtot

Help
~~~~

::

   Input:
   wtot word1 word2 word3 ...

   Output:
   word1: Interpretation of word1
   word2: Interpretation of word2
   word3: Interpretation of word3
   ...
